@@ -183,6 +183,18 @@ class ObjectInfoTest(TestHelper):
         self.variable1 = self.obj_info.variables[Class.prop1]
         self.variable2 = self.obj_info.variables[Class.prop2]
 
+    def test_hashing(self):
+        self.assertEquals(hash(self.obj_info), hash(self.obj_info))
+
+    def test_equals(self):
+        obj_info1 = self.obj_info
+        obj_info2 = get_obj_info(self.Class())
+        self.assertFalse(obj_info1 == obj_info2)
+
+    def test_not_equals(self):
+        obj_info1 = self.obj_info
+        obj_info2 = get_obj_info(self.Class())
+        self.assertTrue(obj_info1 != obj_info2)
 
     def test_dict_subclass(self):
         self.assertTrue(isinstance(self.obj_info, dict))
@@ -499,13 +511,26 @@ class ClassAliasTest(TestHelper):
         statement = compile(self.ClassAlias)
         self.assertEquals(statement, "alias")
 
+    def test_compile_with_reserved_keyword(self):
+        Alias = ClassAlias(self.Class, "select")
+        statement = compile(Alias)
+        self.assertEquals(statement, '"select"')
+
     def test_compile_in_select(self):
         expr = Select(self.ClassAlias.prop1, self.ClassAlias.prop1 == 1,
                       self.ClassAlias)
         statement = compile(expr)
         self.assertEquals(statement,
-                          "SELECT alias.column1 FROM table AS alias "
-                          "WHERE alias.column1 = ?")
+                          'SELECT alias.column1 FROM "table" AS alias '
+                          'WHERE alias.column1 = ?')
+
+    def test_compile_in_select_with_reserved_keyword(self):
+        Alias = ClassAlias(self.Class, "select")
+        expr = Select(Alias.prop1, Alias.prop1 == 1, Alias)
+        statement = compile(expr)
+        self.assertEquals(statement,
+                          'SELECT "select".column1 FROM "table" AS "select" '
+                          'WHERE "select".column1 = ?')
 
 
 class TypeCompilerTest(TestHelper):
